%define pypi_name	tables

Summary: 	Hierarchical datasets in Python
Name: 	 	python-%{pypi_name}
Version: 	3.10.1
Release: 	%mkrel 2
License: 	BSD
Group: 	 	Development/Python
Url: 	 	https://pypi.org/project/tables
Source0: 	%{pypi_source}
BuildRequires:	pyproject-rpm-macros
BuildRequires:	hdf5-devel >= 1.12
BuildRequires:	pkgconfig(bzip2)
BuildRequires:	pkgconfig(lzo2)
BuildRequires:	pkgconfig(blosc)
BuildRequires:	pkgconfig(blosc2)

%description
PyTables is a Python package for managing hierarchical datasets
designed to efficiently and easily cope with extremely large amounts
of data. It is built on top of the HDF5 library and the NumPy package
(numarray and Numeric are also supported). PyTables features an
object-oriented interface and performance-critical extensions coded in
C (generated using Pyrex) that make it a fast yet extremely
easy-to-use tool for interactively processing and searching through
very large amounts of data. PyTables also optimizes memory and disk
resources so that data occupies much less space than with other
solutions such as relational or object-oriented databases (especially
when compression is used).

%package	doc
Group:		Development/Python
Summary:	Documentation for PyTables
BuildArch:	noarch

%description doc
The %{name}-doc package contains the documentation related to
PyTables.

%package -n python3-%{pypi_name}
Summary:        Hierarchical datasets in Python 3
Group:          Development/Python
Requires:	python3-numpy
Requires:	python3-numexpr
BuildRequires:	python3-numpy-devel
BuildRequires:	python3dist(numexpr)
BuildRequires:	python3dist(setuptools)
BuildRequires:	python3dist(six)
BuildRequires:	python3dist(mock)
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3dist(cython)
BuildRequires:  python3dist(sphinx)
BuildRequires:  python3dist(typing-extensions)

%{?python_provide:%python_provide python3-%{pypi_name}}

%description -n python3-%{pypi_name}
PyTables is a Python 3 package for managing hierarchical datasets
designed to efficiently and easily cope with extremely large amounts
of data. It is built on top of the HDF5 library and the NumPy package
(numarray and Numeric are also supported). PyTables features an
object-oriented interface and performance-critical extensions coded in
C (generated using Pyrex) that make it a fast yet extremely
easy-to-use tool for interactively processing and searching through
very large amounts of data. PyTables also optimizes memory and disk
resources so that data occupies much less space than with other
solutions such as relational or object-oriented databases (especially
when compression is used).


%prep
%autosetup -p1 -n %{pypi_name}-%{version}

# Make sure we are not using anything from the bundled blosc by mistake
find c-blosc -mindepth 1 -maxdepth 1 -name hdf5 -prune -o -exec rm -r {} +

find utils -name 'pt*' | xargs sed -i '1s|^#!/usr/bin/env python|#!%{python3}|'

#generate_buildrequires
#pyproject_buildrequires

%build
export LIBS="dl m"
# Remove old c files and regenerate from cython
make distclean
%pyproject_wheel

%install
chmod -x examples/check_examples.sh
for i in utils/*; do sed -i 's|bin/env |bin/|' $i; done

%pyproject_install
%pyproject_save_files tables

%check
libdir=`ls build/|grep lib`
export PYTHONPATH=`pwd`/build/$libdir
echo "import tables; tables.test()" > bench/check_all.py
%{python3} bench/check_all.py

%files doc
%doc examples/
%doc doc/source/

%files -n python3-%{pypi_name} -f %{pyproject_files}
%doc README.rst LICENSES
%{_bindir}/pt2to3
%{_bindir}/ptdump
%{_bindir}/ptrepack
%{_bindir}/pttree



%changelog
* Mon Mar 03 2025 wally <wally> 3.10.1-2.mga10
+ Revision: 2160064
- rebuild for python3.13

* Tue Sep 10 2024 daviddavid <daviddavid> 3.10.1-1.mga10
+ Revision: 2094925
- new version: 3.10.1
- rebuild for new hdf5 1.14.4.3

* Thu Jul 25 2024 daviddavid <daviddavid> 3.9.2-3.mga10
+ Revision: 2082568
- rebuild for new blosc2 2.15.0

* Fri May 10 2024 papoteur <papoteur> 3.9.2-2.mga10
+ Revision: 2063318
- rebuild for blosc2 2.14.4

* Sat Feb 24 2024 daviddavid <daviddavid> 3.9.2-1.mga10
+ Revision: 2043829
- new version: 3.9.2
- rebuild for py3.12

* Mon Dec 05 2022 eatdirt <eatdirt> 3.7.0-2.mga9
+ Revision: 1918331
- Rebuild for new hdf5

* Wed Sep 07 2022 neoclust <neoclust> 3.7.0-1.mga9
+ Revision: 1885329
- New version  	3.7.0

* Fri Apr 01 2022 umeabot <umeabot> 3.6.1-4.mga9
+ Revision: 1838172
- Mageia 9 Mass Rebuild

* Sun Feb 13 2022 neoclust <neoclust> 3.6.1-3.mga9
+ Revision: 1774017
- Rebuild for python 3.10

* Tue Jan 12 2021 daviddavid <daviddavid> 3.6.1-2.mga9
+ Revision: 1671243
- obsolete old python2-tables
- drop bundled egg-info

* Sun Nov 15 2020 guillomovitch <guillomovitch> 3.6.1-1.mga8
+ Revision: 1646366
- new version 3.6.1

* Sun Feb 16 2020 umeabot <umeabot> 3.5.2-2.mga8
+ Revision: 1535074
- Mageia 8 Mass Rebuild

* Thu Oct 10 2019 joequant <joequant> 3.5.2-1.mga8
+ Revision: 1451114
- regenerate cython files for 3.8
+ daviddavid <daviddavid>
- new version: 3.5.2
- add patch to fix build with python3.8
+ tv <tv>
- rebuild for python-3.8
- drop python2 subpkg

* Sat May 25 2019 daviddavid <daviddavid> 3.4.4-4.mga7
+ Revision: 1399089
- backport patches from upstream for numpy 1.16 compatibility
- use system blosc
- rebuild for new hdf5 1.10.5

* Tue Jan 08 2019 tv <tv> 3.4.4-3.mga7
+ Revision: 1351969
- rebuild with python 3.7

* Fri Nov 09 2018 joequant <joequant> 3.4.4-2.mga7
+ Revision: 1329219
- upgrade to hdf5 1.10

* Thu Nov 08 2018 daviddavid <daviddavid> 3.4.4-1.mga7
+ Revision: 1328969
- new version: 3.4.4
- rebuild for new hdf5 1.10.4
- rename python-tables to python2-tables
- use new python macros

* Sun Sep 23 2018 umeabot <umeabot> 3.2.2-5.mga7
+ Revision: 1300609
- Mageia 7 Mass Rebuild

* Sat Aug 05 2017 pterjan <pterjan> 3.2.2-4.mga7
+ Revision: 1135656
- Rebuild for python 3.6

* Tue Feb 16 2016 umeabot <umeabot> 3.2.2-3.mga6
+ Revision: 962461
- Mageia 6 Mass Rebuild

* Thu Oct 08 2015 joequant <joequant> 3.2.2-2.mga6
+ Revision: 887570
- upgrade to python 3.5

* Tue Sep 29 2015 joequant <joequant> 3.2.2-1.mga6
+ Revision: 884967
- upgrade to 3.2.2

* Mon Jul 20 2015 joequant <joequant> 3.2.0-2.mga6
+ Revision: 855651
- rebuild with new hdf5

* Thu Jul 16 2015 joequant <joequant> 3.2.0-1.mga6
+ Revision: 854659
- upgrade to 3.2.0
+ umeabot <umeabot>
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 3.1.1-6.mga5
+ Revision: 729878
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 3.1.1-5.mga5
+ Revision: 688375
- Mageia 5 Mass Rebuild

* Fri Jul 25 2014 joequant <joequant> 3.1.1-4.mga5
+ Revision: 656435
- rebuild with new hdf5
- recompile for new HDF5

* Sat May 31 2014 pterjan <pterjan> 3.1.1-2.mga5
+ Revision: 629053
- Rebuild for new Python

* Fri Apr 25 2014 philippem <philippem> 3.1.1-1.mga5
+ Revision: 618077
- update to 3.1.1

* Tue Oct 22 2013 umeabot <umeabot> 3.0.0-4.mga4
+ Revision: 544578
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 3.0.0-3.mga4
+ Revision: 499522
- Rebuild to add different pythonegg provides for python 2 and 3

* Tue Jul 16 2013 fwang <fwang> 3.0.0-2.mga4
+ Revision: 455002
- rebuild for new hdf5

* Sat Jul 06 2013 philippem <philippem> 3.0.0-1.mga4
+ Revision: 450396
- Update to 3.0.0 , add Python 3

* Sun Jan 13 2013 umeabot <umeabot> 2.3.1-2.mga3
+ Revision: 379554
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Oct 30 2011 lebedov <lebedov> 2.3.1-1.mga2
+ Revision: 159903
- Update to 2.3.1.

* Mon Sep 26 2011 lebedov <lebedov> 2.3-1.mga2
+ Revision: 148858
- Update to 2.3.

* Sun Sep 18 2011 lebedov <lebedov> 2.2.1-1.mga2
+ Revision: 145203
- Update spec file.
- imported package python-tables

